@@ -31,9 +31,9 @@
 
 #include <iostream>
 #include <vector>
-#include "../include/PlayerBase.h"
-#include "../include/Qt/PlayerPrivate.h"
-#include "../include/RendererBase.h"
+#include "PlayerBase.h"
+#include "Qt/PlayerPrivate.h"
+#include "RendererBase.h"
 
 using namespace std;
 
@@ -56,6 +56,9 @@ namespace openshot
 	/// Default destructor
 	virtual ~QtPlayer();
 
+	/// Close audio device
+	void CloseAudioDevice();
+
 	/// Play the video
 	void Play();
 	
@@ -72,7 +75,7 @@ namespace openshot
 	int Position();
 	
 	/// Seek to a specific frame in the player
-	void Seek(int new_frame);
+	void Seek(int64_t new_frame);
 
 	/// Set the source URL/path of this player (which will create an internal Reader)
 	void SetSource(const std::string &source);
@@ -80,10 +83,10 @@ namespace openshot
 	/// Set the QWidget which will be used as the display (note: QLabel works well). This does not take a
 	/// normal pointer, but rather a LONG pointer id (and it re-casts the QWidget pointer inside libopenshot).
 	/// This is required due to SIP and SWIG incompatibility in the Python bindings.
-	void SetQWidget(long long qwidget_address);
+	void SetQWidget(int64_t qwidget_address);
 
 	/// Get the Renderer pointer address (for Python to cast back into a QObject)
-	long long GetRendererQObject();
+	int64_t GetRendererQObject();
 
 	/// Get the Playback speed
 	float Speed();
